Bli medlem

Gå till startsidan
Kom ihåg mig Glömt ditt lösenord?
Bli medlem Logga in via Facebook

- Start
- Forum
  - Forum
    - Senaste inläggen
    - Skapa en ny tråd
    - Mina favoriter
    - Mina trådar
    - Grupper
  - Kategorier
    - Adoption
    - Ekonomi & juridik
    - Familjeliv.se
    - Fritid & hobby
    - Fråga experten
  - 5
    - Förälder
    - Gravid
    - Hus & hem
    - Husdjur
    - Kropp & själ
  - 10
    - Känsliga rummet
    - Nöje
    - Pappagrupp
    - Planerar barn
    - Samhälle
  - 15
    - Sandlådan
    - Sex & samlevnad
    - Svårt att få barn
    - änglarum
- Bloggar
  - Bloggar
    - Föräldrafitness
    - Helt enkelt Fi
    - Lidingömamman
    - Lisa Abefelt
    - Malin Wollin
    - Vårt dagliga vuxenkrux
- Planerar barn
- Väntar barn
- Förälder
- Övrigt
  - Övrigt
    - Clearblue
    - Fråga experten
    - Första tiden hemma
    - Lekliv
    - Matliv
    - Min förlossning
    - Pampers
    - Resliv
    - Semper
    - Webb-TV

Bli medlem
E-post
Användarnamn
Kön
Kvinna Man
Roll
När väntar du barn?
Beräknad förlossning
-
-
Hur många barn har du?

Lägg till fler barn
Jag vill ta emot Familjelivs medlemsbrev
Jag vill ta emot erbjudanden från våra partners
Jag har läst och förstått medlemsvillkoren
Läs medlemsvillkoren

## Annat innehåll

### BLOGG

### Så gör du godaste adventstårtan med smak av saffran & lingon

Blogg-Lisa guidar dig genom receptet.

### Tv

### Serie-maraton: TV-serierna du verkligen inte vill missa i december

Viaplay - 27 nov
Supervinter för serieälskare.
Publicerad 27 november 2014 Uppdaterad 3 december 2014

### JULKALENDER

### Vinn fina & lyxiga priser varje dag ända fram till jul i kalendern

I samarbete med LEGO.

### shopping

### Julbonus – på allt.
Julhandla och få bonus rätt in på bankkontot.

Kampanj - 5 dec
I samarbete med Bonusbay
Publicerad 5 december 2014 Uppdaterad 10 december 2014

### BILDEXTRA

### Kommer du ihåg alla de senaste årens julklappar?

Colossus Jul - 25 nov
Årets julklapp 2014 är utsedd.
Publicerad 25 november 2014 Uppdaterad 3 december 2014

### teknik

### Office 365, det enda kontorsprogrammet du och din familj behöver

Kampanj - 27 nov
I samarbete med Microsoft
Publicerad 27 november 2014 Uppdaterad 10 december 2014

### FORUM

###
Jag älskar julen, nästan lite sjukt

Här möts vi i forumet som älskar julen

### Djurrätt

### Djurvänligare jul med Sveriges största djurrättsorganisation

Kampanj - 27 nov
I samarbete med Djurens Rätt.
Publicerad 27 november 2014 Uppdaterad 1 december 2014

### Hetaste debatterna

"Jaha heter hon SÅ, det var ju speciellt..." Klass-diskussion ang dotters namn.. Ställ in julen, bonus är ju inte här:( Mobbingen mot SD Min man runkar med vårt barn bredvid sig Dagis/dagmamma redan från 3 månader, är det så förfärligt?